--- title: "wallaroo.standalone_client" type: docs linkTitle: "wallaroo.standalone_client" ---
class StandaloneClient:
StandaloneClient( host: str, port: int, model: Optional[wallaroo.model.Model] = None, pipeline_config: Optional[wallaroo.pipeline_config.PipelineConfig] = None, interactive: Optional[bool] = None)
def status(self) -> Dict[str, Any]:

Returns a dict of standalone engine model status.

Example: {'models': [{'class': 'ccfraud', 'name': 'z5', 'status': 'Running'}]}

Example: {'models': [{'class': 'postprocess', 'name': 'first-postprocess', 'status': 'Running'}, {'class': 'noopfloats', 'name': 'noopv1', 'status': 'Running'}, {'class': 'preprocess', 'name': 'first-preprocess', 'status': 'Running'}]}

Example: {"models": [{"class":"synerror", "name":"v1", "status":{"Error":"Python compile or runtime error [" File \"//tmp/.tmpk7mJpI/syntax_error.py\", line 1", " PLEASE CRASH HERE", " ^", "SyntaxError: invalid syntax"]"}}]}

def infer( self, tensor: Dict[str, Any]) -> List[wallaroo.inference_result.InferenceResult]:
def infer_from_file( self, filename: Union[str, pathlib.Path]) -> List[wallaroo.inference_result.InferenceResult]: